<?php

/**
 *  Copyright (C) 2020 OTP Mobil Kft.
 *
 *  PHP version 7
 *
 *  This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  SDK
 * @package   SimplePayV2_SDK
 * @author    SimplePay IT Support <itsupport@otpmobil.com>
 * @copyright 2020 OTP Mobil Kft.
 * @license   http://www.gnu.org/licenses/gpl-3.0.html  GNU GENERAL PUBLIC LICENSE (GPL V3.0)
 * @link      http://simplepartner.hu/online_fizetesi_szolgaltatas.html
 */

//Optional error riporting
error_reporting(E_ALL);
ini_set('display_errors', '1');

 //Import config data
require_once 'src/config.php';

//Import SimplePayment class
require_once 'src/SimplePayV21.php';
require_once 'src/SimplePayV21Auto.php';

$trx = new SimplePayAuto;

//add config data other
$trx->addConfig($config);


//card data
//-----------------------------------------------------------------------------------------
//success
$trx->addGroupData('cardData', 'number', '4908366099900425');
//fail
//$trx->addGroupData('cardData', 'number', '4111111111111111');
$trx->addGroupData('cardData', 'expiry', '0122');
$trx->addGroupData('cardData', 'cvc', '123');
$trx->addGroupData('cardData', 'holder', 'V2 AUTO test');


//3DS section
//-----------------------------------------------------------------------------------------
    /**
     * In case of merchant's own 3DS MPI
     */
/*
        $trx->addGroupData('3DSecExternal', 'xid', '01234567980123456789');
        $trx->addGroupData('3DSecExternal', 'eci', '01');
        $trx->addGroupData('3DSecExternal', 'cavv', 'ABCDEF');
*/

    /**
     * In case of 3DS of SimplePay
     */
    $type = 'CIT';
if (isset($_REQUEST['type'])) {
    $type = $_REQUEST['type'];
}
    $trx->addData('type', $type);


    //transactions with user presence
    //-----------------------------------------------------------------------------------------
if ($type == 'CIT') {
    $serverData = [
    'accept' => $_SERVER['HTTP_ACCEPT'],
    'agent' => $_SERVER['HTTP_USER_AGENT'],
    'ip' => $_SERVER['REMOTE_ADDR']
    ];

    if (isset($serverData)) {
        $trx->addGroupData('browser', 'accept', $serverData['accept']);
        $trx->addGroupData('browser', 'agent', $serverData['agent']);
        $trx->addGroupData('browser', 'ip', $serverData['ip']);
    }

    if (isset($_REQUEST['browser'])) {
        $browserData = json_decode(base64_decode($_REQUEST['browser']));
        $trx->addGroupData('browser', 'java', $browserData->java);
        $trx->addGroupData('browser', 'lang', $browserData->lang);
        $trx->addGroupData('browser', 'color', $browserData->color);
        $trx->addGroupData('browser', 'height', $browserData->height);
        $trx->addGroupData('browser', 'width', $browserData->width);
        $trx->addGroupData('browser', 'tz', $browserData->tz);
    }

    // Challenge REDIRECT URL for CIT transactions
    //-----------------------------------------------------------------------------------------
    // common URL for all result
    $trx->addData('url', $config['URL']);
}

    //order price / total
    //-----------------------------------------------------------------------------------------
    $trx->addData('total', '100');

    /*
    $trx->addItems(array(
        'ref' => 'Product ID',
        'title' => 'Product name',
        'description' => 'Product description',
        'amount' => '1',
        'price' => '100',
        'tax' => '0',
        )
    );
    */


    //shipping cost
    //-----------------------------------------------------------------------------------------
    //$trx->addData('shippingCost', 20);


    //discount
    //-----------------------------------------------------------------------------------------
    //$trx->addData('discount', 10);


    //currency
    //-----------------------------------------------------------------------------------------
    $trx->addData('currency', 'HUF');


    //order reference number
    //uniq oreder reference number in the merchant system
    //-----------------------------------------------------------------------------------------
    $trx->addData('orderRef', str_replace(array('.', ':', '/'), "", @$_SERVER['SERVER_ADDR']) . @date("U", time()) . rand(1000, 9999));


    //customer's name
    //-----------------------------------------------------------------------------------------
    //$trx->addData('customer', 'v2 AUTO Tester');


    //customer's email
    //-----------------------------------------------------------------------------------------
    $trx->addData('customerEmail', 'sdk_test@otpmobil.com');


    //language
    //HU, EN, DE, etc.
    //-----------------------------------------------------------------------------------------
    $trx->addData('language', 'HU');


    // customer's registration mehod
    // 01: guest
    // 02: registered
    // 05: third party
    //-----------------------------------------------------------------------------------------
    $trx->addData('threeDSReqAuthMethod', '02');


    // INVOICE DATA
    //-----------------------------------------------------------------------------------------
    $trx->addGroupData('invoice', 'name', 'SimplePay V2 Tester');
    //$trx->addGroupData('invoice', 'company', '');
    $trx->addGroupData('invoice', 'country', 'hu');
    $trx->addGroupData('invoice', 'state', 'Budapest');
    $trx->addGroupData('invoice', 'city', 'Budapest');
    $trx->addGroupData('invoice', 'zip', '1111');
    $trx->addGroupData('invoice', 'address', 'Address 1');
    //$trx->addGroupData('invoice', 'address2', '');
    //$trx->addGroupData('invoice', 'phone', '06203164978');


    /*
    // DELIVERY DATA
    //-----------------------------------------------------------------------------------------
    $trx->addGroupData('delivery', 'name', 'SimplePay V2 Tester');
    $trx->addGroupData('delivery', 'company', '');
    $trx->addGroupData('delivery', 'country', 'hu');
    $trx->addGroupData('delivery', 'state', 'Budapest');
    $trx->addGroupData('delivery', 'city', 'Budapest');
    $trx->addGroupData('delivery', 'zip', '1111');
    $trx->addGroupData('delivery', 'address', 'Address 1');
    $trx->addGroupData('delivery', 'address2', '');
    $trx->addGroupData('delivery', 'phone', '06203164978');
    */


    //start transaction with card data
    //-----------------------------------------------------------------------------------------
    $trx->runAuto();


    //Challenge
    //-----------------------------------------------------------------------------------------
    $transactionBase = $trx->getTransactionBase();
if ($trx->config['autoChallenge'] && isset($v2AutoResult['redirectUrl']) && $transactionBase['type'] === 'CIT') {
    $trx->formDetails['element'] = 'auto';
    $trx->challenge($v2AutoResult);
}


    //test data
    //-----------------------------------------------------------------------------------------
    print "API REQUEST";
    print "<pre>";
    print_r($trx->getTransactionBase());
    print "</pre>";

    print "API RESULT";
    print "<pre>";
    print_r($trx->getReturnData());
    print "</pre>";
